# biotrainer files example

This example notebook explains, how to work with files used or created by biotrainer. It shows utility functions
built-in to biotrainer that make working with these files easy.

1. Input fasta files
2. Out.yml files